"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeDer = exports.encodeDer = void 0;
var jsbn_1 = require("jsbn");
function bigintToValue(bigint) {
    var h = bigint.toString(16);
    if (h[0] !== '-') {
        // 正数
        if (h.length % 2 === 1)
            h = '0' + h;
        // 补齐到整字节
        else if (!h.match(/^[0-7]/))
            h = '00' + h; // 非0开头，则补一个全0字节
    }
    else {
        // 负数
        h = h.substr(1);
        var len = h.length;
        if (len % 2 === 1)
            len += 1;
        // 补齐到整字节
        else if (!h.match(/^[0-7]/))
            len += 2; // 非0开头，则补一个全0字节
        var mask = '';
        for (var i = 0; i < len; i++)
            mask += 'f';
        mask = new jsbn_1.BigInteger(mask, 16);
        // 对绝对值取反，加1
        h = mask.xor(bigint).add(jsbn_1.BigInteger.ONE);
        h = h.toString(16).replace(/^-/, '');
    }
    return h;
}
var ASN1Object = /** @class */ (function () {
    function ASN1Object() {
        this.tlv = null;
        this.t = '00';
        this.l = '00';
        this.v = '';
    }
    /**
     * 获取 der 编码比特流16进制串
     */
    ASN1Object.prototype.getEncodedHex = function () {
        if (!this.tlv) {
            this.v = this.getValue();
            this.l = this.getLength();
            this.tlv = this.t + this.l + this.v;
        }
        return this.tlv;
    };
    ASN1Object.prototype.getLength = function () {
        var n = this.v.length / 2; // 字节数
        var nHex = n.toString(16);
        if (nHex.length % 2 === 1)
            nHex = '0' + nHex; // 补齐到整字节
        if (n < 128) {
            // 短格式，以 0 开头
            return nHex;
        }
        else {
            // 长格式，以 1 开头
            var head = 128 + nHex.length / 2; // 1(1位) + 真正的长度占用字节数(7位) + 真正的长度
            return head.toString(16) + nHex;
        }
    };
    ASN1Object.prototype.getValue = function () {
        return '';
    };
    return ASN1Object;
}());
var DERInteger = /** @class */ (function (_super) {
    __extends(DERInteger, _super);
    function DERInteger(bigint) {
        var _this = _super.call(this) || this;
        _this.t = '02'; // 整型标签说明
        if (bigint)
            _this.v = bigintToValue(bigint);
        return _this;
    }
    DERInteger.prototype.getValue = function () {
        return this.v;
    };
    return DERInteger;
}(ASN1Object));
var DERSequence = /** @class */ (function (_super) {
    __extends(DERSequence, _super);
    function DERSequence(asn1Array) {
        var _this = _super.call(this) || this;
        _this.t = '30'; // 序列标签说明
        _this.asn1Array = asn1Array;
        return _this;
    }
    DERSequence.prototype.getValue = function () {
        this.v = this.asn1Array
            .map(function (asn1Object) { return asn1Object.getEncodedHex(); })
            .join('');
        return this.v;
    };
    return DERSequence;
}(ASN1Object));
/**
 * 获取 l 占用字节数
 */
function getLenOfL(str, start) {
    if (+str[start + 2] < 8)
        return 1; // l 以0开头，则表示短格式，只占一个字节
    return +str.substr(start + 2, 2) & (0x7f + 1); // 长格式，取第一个字节后7位作为长度真正占用字节数，再加上本身
}
/**
 * 获取 l
 */
function getL(str, start) {
    // 获取 l
    var len = getLenOfL(str, start);
    var l = str.substr(start + 2, len * 2);
    if (!l)
        return -1;
    var bigint = +l[0] < 8 ? new jsbn_1.BigInteger(l, 16) : new jsbn_1.BigInteger(l.substr(2), 16);
    return bigint.intValue();
}
/**
 * 获取 v 的位置
 */
function getStartOfV(str, start) {
    var len = getLenOfL(str, start);
    return start + (len + 1) * 2;
}
/**
 * ASN.1 der 编码，针对 sm2 签名
 */
function encodeDer(r, s) {
    var derR = new DERInteger(r);
    var derS = new DERInteger(s);
    var derSeq = new DERSequence([derR, derS]);
    return derSeq.getEncodedHex();
}
exports.encodeDer = encodeDer;
/**
 * 解析 ASN.1 der，针对 sm2 验签
 */
function decodeDer(input) {
    // 结构：
    // input = | tSeq | lSeq | vSeq |
    // vSeq = | tR | lR | vR | tS | lS | vS |
    var start = getStartOfV(input, 0);
    var vIndexR = getStartOfV(input, start);
    var lR = getL(input, start);
    var vR = input.substr(vIndexR, lR * 2);
    var nextStart = vIndexR + vR.length;
    var vIndexS = getStartOfV(input, nextStart);
    var lS = getL(input, nextStart);
    var vS = input.substr(vIndexS, lS * 2);
    var r = new jsbn_1.BigInteger(vR, 16);
    var s = new jsbn_1.BigInteger(vS, 16);
    return { r: r, s: s };
}
exports.decodeDer = decodeDer;
//# sourceMappingURL=asn1.js.map