import { OrgManagementClient } from './OrgManagementClient';
import { ManagementClientOptions } from './types';
import { UserPoolManagementClient } from './UserpoolManagementClient';
import { UsersManagementClient } from './UsersManagementClient';
import { EmailScene } from '../../types/graphql.v2';
import { User } from "../../types/index";
import { AxiosRequestConfig } from 'axios';
import { RolesManagementClient } from './RolesManagementClient';
import { PoliciesManagementClient } from './PoliciesManagementClient';
import { UdfManagementClient } from './UdfManagementClient';
import { GroupsManagementClient } from './GroupsManagementClient';
import { AclManagementClient } from './AclManagementClient';
import { WhitelistManagementClient } from './WhitelistManagementClient';
import { StatisticsManagementClient } from './StatisticsManagementClient';
import { UserActionManagementClient } from './UserActionManagementClient';
import { ApplicationsManagementClient } from './ApplicationsManagementClient';
import { MFAManagementClient } from './MFAManagementClient';
import { Lang } from '../../types';
import { PrincipalManagementClient } from './PrincipalManagement';
import { TenantManagementClient } from './TenantManagementClient';
import { EventManagementClient } from './EventManagementClient';
import { BrowserFingerprintClient } from './BrowserFingerprintClient';
export declare class ManagementClient {
    options: ManagementClientOptions;
    private graphqlClient;
    private httpClient;
    private fastHttpClient;
    private tokenProvider;
    private publicKeyManager;
    users: UsersManagementClient;
    userpool: UserPoolManagementClient;
    acl: AclManagementClient;
    org: OrgManagementClient;
    roles: RolesManagementClient;
    policies: PoliciesManagementClient;
    udf: UdfManagementClient;
    groups: GroupsManagementClient;
    whitelist: WhitelistManagementClient;
    statistics: StatisticsManagementClient;
    userAction: UserActionManagementClient;
    applications: ApplicationsManagementClient;
    mfa: MFAManagementClient;
    principal: PrincipalManagementClient;
    tenant: TenantManagementClient;
    event: EventManagementClient;
    browserFingerprint: BrowserFingerprintClient;
    constructor(options: ManagementClientOptions);
    /**
     * @description 发送邮件
     * @param email: 邮件
     * @param scene: 发送场景
     *
     */
    sendEmail(email: string, scene: EmailScene): Promise<{
        message?: string;
        code?: number;
    }>;
    /**
     * @description 检测登录状态
     *
     */
    checkLoginStatus(token: string, options?: {
        fetchUserDetail?: boolean;
    }): Promise<User>;
    /**
     * @name isPasswordValid
     * @name_zh 检测密码是否合法
     * @description 检测密码是否合法
     *
     * @param {string} password 密码
     *
     * @example
     *
     * const envList = await managementClient.isPasswordValid('xxxxxx')
     *
     * @returns {Promise<{
     *  valid: boolean
     *  message: string
     * }>} 返回检测结果
     * @memberof ManagementClient
     */
    isPasswordValid(password: string): Promise<{
        valid: boolean;
        message: string;
    }[]>;
    /**
     * @description 设置语言
     */
    setLang(lang: Lang): void;
    /**
     * @description 执行 GraphQL 请求
     */
    makeGraphqlRequest(options: {
        query: string;
        variables?: any;
    }): Promise<any>;
    /**
     * @description 执行 RESTful 请求
     */
    makeRestRequest(config: AxiosRequestConfig): Promise<any>;
}
