var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { BigInteger } from 'jsbn';
import { encodeDer, decodeDer } from './asn1';
import * as _ from './utils';
import sm3 from './sm3';
var _a = _.generateEcparam(), G = _a.G, curve = _a.curve, n = _a.n;
var C1C2C3 = 0;
/**
 * 加密
 */
function doEncrypt(msg, publicKey, cipherMode) {
    if (cipherMode === void 0) { cipherMode = 1; }
    msg =
        typeof msg === 'string'
            ? _.hexToArray(_.utf8ToHex(msg))
            : Array.prototype.slice.call(msg);
    publicKey = _.getGlobalCurve().decodePointHex(publicKey); // 先将公钥转成点
    var keypair = _.generateKeyPairHex();
    var k = new BigInteger(keypair.privateKey, 16); // 随机数 k
    // c1 = k * G
    var c1 = keypair.publicKey;
    if (c1.length > 128)
        c1 = c1.substr(c1.length - 128);
    // (x2, y2) = k * publicKey
    var p = publicKey.multiply(k);
    var x2 = _.hexToArray(_.leftPad(p
        .getX()
        .toBigInteger()
        .toRadix(16), 64));
    var y2 = _.hexToArray(_.leftPad(p
        .getY()
        .toBigInteger()
        .toRadix(16), 64));
    // c3 = hash(x2 || msg || y2)
    var c3 = _.arrayToHex(sm3([].concat(x2, msg, y2)));
    var ct = 1;
    var offset = 0;
    var t = []; // 256 位
    var z = [].concat(x2, y2);
    var nextT = function () {
        // (1) Hai = hash(z || ct)
        // (2) ct++
        t = sm3(__spreadArray(__spreadArray([], z, true), [
            (ct >> 24) & 0x00ff,
            (ct >> 16) & 0x00ff,
            (ct >> 8) & 0x00ff,
            ct & 0x00ff
        ], false));
        ct++;
        offset = 0;
    };
    nextT(); // 先生成 Ha1
    for (var i = 0, len = msg.length; i < len; i++) {
        // t = Ha1 || Ha2 || Ha3 || Ha4
        if (offset === t.length)
            nextT();
        // c2 = msg ^ t
        msg[i] ^= t[offset++] & 0xff;
    }
    var c2 = _.arrayToHex(msg);
    return cipherMode === C1C2C3 ? c1 + c2 + c3 : c1 + c3 + c2;
}
/**
 * 解密
 */
function doDecrypt(encryptData, privateKey, cipherMode, _a) {
    if (cipherMode === void 0) { cipherMode = 1; }
    var _b = _a === void 0 ? {} : _a, _c = _b.output, output = _c === void 0 ? 'string' : _c;
    privateKey = new BigInteger(privateKey, 16);
    var c3 = encryptData.substr(128, 64);
    var c2 = encryptData.substr(128 + 64);
    if (cipherMode === C1C2C3) {
        c3 = encryptData.substr(encryptData.length - 64);
        c2 = encryptData.substr(128, encryptData.length - 128 - 64);
    }
    var msg = _.hexToArray(c2);
    var c1 = _.getGlobalCurve().decodePointHex('04' + encryptData.substr(0, 128));
    var p = c1.multiply(privateKey);
    var x2 = _.hexToArray(_.leftPad(p
        .getX()
        .toBigInteger()
        .toRadix(16), 64));
    var y2 = _.hexToArray(_.leftPad(p
        .getY()
        .toBigInteger()
        .toRadix(16), 64));
    var ct = 1;
    var offset = 0;
    var t = []; // 256 位
    var z = [].concat(x2, y2);
    var nextT = function () {
        // (1) Hai = hash(z || ct)
        // (2) ct++
        t = sm3(__spreadArray(__spreadArray([], z, true), [
            (ct >> 24) & 0x00ff,
            (ct >> 16) & 0x00ff,
            (ct >> 8) & 0x00ff,
            ct & 0x00ff
        ], false));
        ct++;
        offset = 0;
    };
    nextT(); // 先生成 Ha1
    for (var i = 0, len = msg.length; i < len; i++) {
        // t = Ha1 || Ha2 || Ha3 || Ha4
        if (offset === t.length)
            nextT();
        // c2 = msg ^ t
        msg[i] ^= t[offset++] & 0xff;
    }
    // c3 = hash(x2 || msg || y2)
    var checkC3 = _.arrayToHex(sm3([].concat(x2, msg, y2)));
    if (checkC3 === c3) {
        return output === 'array' ? msg : _.arrayToUtf8(msg);
    }
    else {
        return output === 'array' ? [] : '';
    }
}
/**
 * 签名
 */
function doSignature(msg, privateKey, _a) {
    var _b = _a === void 0 ? {} : _a, pointPool = _b.pointPool, der = _b.der, hash = _b.hash, publicKey = _b.publicKey, userId = _b.userId;
    var hashHex = typeof msg === 'string' ? _.utf8ToHex(msg) : _.arrayToHex(msg);
    if (hash) {
        // sm3杂凑
        publicKey = publicKey || getPublicKeyFromPrivateKey(privateKey);
        hashHex = getHash(hashHex, publicKey, userId);
    }
    var dA = new BigInteger(privateKey, 16);
    var e = new BigInteger(hashHex, 16);
    // k
    var k = null;
    var r = null;
    var s = null;
    do {
        do {
            var point = void 0;
            if (pointPool && pointPool.length) {
                point = pointPool.pop();
            }
            else {
                point = getPoint();
            }
            k = point.k;
            // r = (e + x1) mod n
            r = e.add(point.x1).mod(n);
        } while (r.equals(BigInteger.ZERO) || r.add(k).equals(n));
        // s = ((1 + dA)^-1 * (k - r * dA)) mod n
        s = dA
            .add(BigInteger.ONE)
            .modInverse(n)
            .multiply(k.subtract(r.multiply(dA)))
            .mod(n);
    } while (s.equals(BigInteger.ZERO));
    if (der)
        return encodeDer(r, s); // asn.1 der 编码
    return _.leftPad(r.toString(16), 64) + _.leftPad(s.toString(16), 64);
}
/**
 * 验签
 */
function doVerifySignature(msg, signHex, publicKey, _a) {
    var _b = _a === void 0 ? {} : _a, der = _b.der, hash = _b.hash, userId = _b.userId;
    var hashHex = typeof msg === 'string' ? _.utf8ToHex(msg) : _.arrayToHex(msg);
    if (hash) {
        // sm3杂凑
        hashHex = getHash(hashHex, publicKey, userId);
    }
    var r;
    var s;
    if (der) {
        var decodeDerObj = decodeDer(signHex); // asn.1 der 解码
        r = decodeDerObj.r;
        s = decodeDerObj.s;
    }
    else {
        r = new BigInteger(signHex.substring(0, 64), 16);
        s = new BigInteger(signHex.substring(64), 16);
    }
    var PA = curve.decodePointHex(publicKey);
    var e = new BigInteger(hashHex, 16);
    // t = (r + s) mod n
    var t = r.add(s).mod(n);
    if (t.equals(BigInteger.ZERO))
        return false;
    // x1y1 = s * G + t * PA
    var x1y1 = G.multiply(s).add(PA.multiply(t));
    // R = (e + x1) mod n
    var R = e.add(x1y1.getX().toBigInteger()).mod(n);
    return r.equals(R);
}
/**
 * sm3杂凑算法
 */
function getHash(hashHex, publicKey, userId) {
    if (userId === void 0) { userId = '1234567812345678'; }
    // z = hash(entl || userId || a || b || gx || gy || px || py)
    userId = _.utf8ToHex(userId);
    var a = _.leftPad(G.curve.a.toBigInteger().toRadix(16), 64);
    var b = _.leftPad(G.curve.b.toBigInteger().toRadix(16), 64);
    var gx = _.leftPad(G.getX()
        .toBigInteger()
        .toRadix(16), 64);
    var gy = _.leftPad(G.getY()
        .toBigInteger()
        .toRadix(16), 64);
    if (publicKey.length > 128)
        publicKey = publicKey.substr(2, 128); // 干掉 '04'
    var px = publicKey.substr(0, 64);
    var py = publicKey.substr(64, 64);
    var data = _.hexToArray(userId + a + b + gx + gy + px + py);
    var entl = userId.length * 4;
    data.unshift(entl & 0x00ff);
    data.unshift((entl >> 8) & 0x00ff);
    var z = sm3(data);
    // e = hash(z || msg)
    return _.arrayToHex(sm3(z.concat(_.hexToArray(hashHex))));
}
/**
 * 计算公钥
 */
function getPublicKeyFromPrivateKey(privateKey) {
    var PA = G.multiply(new BigInteger(privateKey, 16));
    var x = _.leftPad(PA.getX()
        .toBigInteger()
        .toString(16), 64);
    var y = _.leftPad(PA.getY()
        .toBigInteger()
        .toString(16), 64);
    return '04' + x + y;
}
/**
 * 获取椭圆曲线点
 */
function getPoint() {
    var keypair = _.generateKeyPairHex();
    var PA = curve.decodePointHex(keypair.publicKey);
    keypair.k = new BigInteger(keypair.privateKey, 16);
    keypair.x1 = PA.getX().toBigInteger();
    return keypair;
}
export var generateKeyPairHex = _.generateKeyPairHex;
export var verifyPublicKey = _.verifyPublicKey;
export { doEncrypt, doDecrypt, doSignature, doVerifySignature, getPoint };
//# sourceMappingURL=index.js.map